import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.time
import java.time.format
import java.time.temporal
import java.util

class AbstractChronology(Chronology):
    def __init__(self) -> None: ...
    def compareTo(self, other: Chronology, /) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...
    def resolveDate(self, fieldValues: java.util.Map[java.time.temporal.TemporalField, java.lang.Long], resolverStyle: java.time.format.ResolverStyle, /) -> ChronoLocalDate: ...
    def toString(self) -> str: ...

class ChronoLocalDate(java.lang.Comparable[ChronoLocalDate], java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster):
    def adjustInto(self, temporal: java.time.temporal.Temporal, /) -> java.time.temporal.Temporal: ...
    def atTime(self, localTime: java.time.LocalTime, /) -> ChronoLocalDateTime[java.lang.Object]: ...
    def compareTo(self, other: ChronoLocalDate, /) -> int: ...
    def equals(self, arg1: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def format(self, formatter: java.time.format.DateTimeFormatter, /) -> str: ...
    @staticmethod
    def from_(temporal: java.time.temporal.TemporalAccessor, /) -> ChronoLocalDate: ...
    def getChronology(self) -> Chronology: ...
    def getEra(self) -> Era: ...
    def hashCode(self) -> int: ...
    def isAfter(self, other: ChronoLocalDate, /) -> bool: ...
    def isBefore(self, other: ChronoLocalDate, /) -> bool: ...
    def isEqual(self, other: ChronoLocalDate, /) -> bool: ...
    def isLeapYear(self) -> bool: ...
    @typing.overload
    def isSupported(self, field: java.time.temporal.TemporalField, /) -> bool: ...
    @typing.overload
    def isSupported(self, unit: java.time.temporal.TemporalUnit, /) -> bool: ...
    def lengthOfMonth(self) -> int: ...
    def lengthOfYear(self) -> int: ...
    @typing.overload
    def minus(self, amount: java.time.temporal.TemporalAmount, /) -> ChronoLocalDate: ...
    @typing.overload
    def minus(self, amountToSubtract: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> ChronoLocalDate: ...
    @typing.overload
    def plus(self, amount: java.time.temporal.TemporalAmount, /) -> ChronoLocalDate: ...
    @typing.overload
    def plus(self, amountToAdd: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> ChronoLocalDate: ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, query: java.time.temporal.TemporalQuery[_query__R], /) -> _query__R: ...
    @staticmethod
    def timeLineOrder() -> java.util.Comparator[ChronoLocalDate]: ...
    def toEpochDay(self) -> int: ...
    def toString(self) -> str: ...
    @typing.overload
    def until(self, arg1: ChronoLocalDate, /) -> ChronoPeriod: ...
    @typing.overload
    def until(self, arg1: java.time.temporal.Temporal, arg2: java.time.temporal.TemporalUnit, /) -> int: ...
    @typing.overload
    def with_(self, adjuster: java.time.temporal.TemporalAdjuster, /) -> ChronoLocalDate: ...
    @typing.overload
    def with_(self, field: java.time.temporal.TemporalField, newValue: int | java.jlong | java.lang.Long, /) -> ChronoLocalDate: ...

_ChronoLocalDateTime__D = typing.TypeVar('_ChronoLocalDateTime__D')  # <D>
class ChronoLocalDateTime(java.lang.Comparable[ChronoLocalDateTime[java.lang.Object]], java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster, typing.Generic[_ChronoLocalDateTime__D]):
    def adjustInto(self, temporal: java.time.temporal.Temporal, /) -> java.time.temporal.Temporal: ...
    def atZone(self, arg1: java.time.ZoneId, /) -> ChronoZonedDateTime[_ChronoLocalDateTime__D]: ...
    def compareTo(self, other: ChronoLocalDateTime[java.lang.Object], /) -> int: ...
    def equals(self, arg1: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def format(self, formatter: java.time.format.DateTimeFormatter, /) -> str: ...
    @staticmethod
    def from_(temporal: java.time.temporal.TemporalAccessor, /) -> ChronoLocalDateTime[java.lang.Object]: ...
    def getChronology(self) -> Chronology: ...
    def hashCode(self) -> int: ...
    def isAfter(self, other: ChronoLocalDateTime[java.lang.Object], /) -> bool: ...
    def isBefore(self, other: ChronoLocalDateTime[java.lang.Object], /) -> bool: ...
    def isEqual(self, other: ChronoLocalDateTime[java.lang.Object], /) -> bool: ...
    @typing.overload
    def isSupported(self, arg1: java.time.temporal.TemporalField, /) -> bool: ...
    @typing.overload
    def isSupported(self, unit: java.time.temporal.TemporalUnit, /) -> bool: ...
    @typing.overload
    def minus(self, amount: java.time.temporal.TemporalAmount, /) -> ChronoLocalDateTime[_ChronoLocalDateTime__D]: ...
    @typing.overload
    def minus(self, amountToSubtract: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> ChronoLocalDateTime[_ChronoLocalDateTime__D]: ...
    @typing.overload
    def plus(self, amount: java.time.temporal.TemporalAmount, /) -> ChronoLocalDateTime[_ChronoLocalDateTime__D]: ...
    @typing.overload
    def plus(self, arg1: int | java.jlong | java.lang.Long, arg2: java.time.temporal.TemporalUnit, /) -> ChronoLocalDateTime[_ChronoLocalDateTime__D]: ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, query: java.time.temporal.TemporalQuery[_query__R], /) -> _query__R: ...
    @staticmethod
    def timeLineOrder() -> java.util.Comparator[ChronoLocalDateTime[java.lang.Object]]: ...
    def toEpochSecond(self, offset: java.time.ZoneOffset, /) -> int: ...
    def toInstant(self, offset: java.time.ZoneOffset, /) -> java.time.Instant: ...
    def toLocalDate(self) -> _ChronoLocalDateTime__D: ...
    def toLocalTime(self) -> java.time.LocalTime: ...
    def toString(self) -> str: ...
    @typing.overload
    def with_(self, adjuster: java.time.temporal.TemporalAdjuster, /) -> ChronoLocalDateTime[_ChronoLocalDateTime__D]: ...
    @typing.overload
    def with_(self, arg1: java.time.temporal.TemporalField, arg2: int | java.jlong | java.lang.Long, /) -> ChronoLocalDateTime[_ChronoLocalDateTime__D]: ...

class ChronoPeriod(java.time.temporal.TemporalAmount):
    def addTo(self, arg1: java.time.temporal.Temporal, /) -> java.time.temporal.Temporal: ...
    @staticmethod
    def between(startDateInclusive: ChronoLocalDate, endDateExclusive: ChronoLocalDate, /) -> ChronoPeriod: ...
    def equals(self, arg1: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def get(self, arg1: java.time.temporal.TemporalUnit, /) -> int: ...
    def getChronology(self) -> Chronology: ...
    def getUnits(self) -> java.util.List[java.time.temporal.TemporalUnit]: ...
    def hashCode(self) -> int: ...
    def isNegative(self) -> bool: ...
    def isZero(self) -> bool: ...
    def minus(self, arg1: java.time.temporal.TemporalAmount, /) -> ChronoPeriod: ...
    def multipliedBy(self, arg1: int | java.jint | java.lang.Integer, /) -> ChronoPeriod: ...
    def negated(self) -> ChronoPeriod: ...
    def normalized(self) -> ChronoPeriod: ...
    def plus(self, arg1: java.time.temporal.TemporalAmount, /) -> ChronoPeriod: ...
    def subtractFrom(self, arg1: java.time.temporal.Temporal, /) -> java.time.temporal.Temporal: ...
    def toString(self) -> str: ...

_ChronoZonedDateTime__D = typing.TypeVar('_ChronoZonedDateTime__D')  # <D>
class ChronoZonedDateTime(java.lang.Comparable[ChronoZonedDateTime[java.lang.Object]], java.time.temporal.Temporal, typing.Generic[_ChronoZonedDateTime__D]):
    def compareTo(self, other: ChronoZonedDateTime[java.lang.Object], /) -> int: ...
    def equals(self, arg1: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def format(self, formatter: java.time.format.DateTimeFormatter, /) -> str: ...
    @staticmethod
    def from_(temporal: java.time.temporal.TemporalAccessor, /) -> ChronoZonedDateTime[java.lang.Object]: ...
    def get(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getChronology(self) -> Chronology: ...
    def getLong(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getOffset(self) -> java.time.ZoneOffset: ...
    def getZone(self) -> java.time.ZoneId: ...
    def hashCode(self) -> int: ...
    def isAfter(self, other: ChronoZonedDateTime[java.lang.Object], /) -> bool: ...
    def isBefore(self, other: ChronoZonedDateTime[java.lang.Object], /) -> bool: ...
    def isEqual(self, other: ChronoZonedDateTime[java.lang.Object], /) -> bool: ...
    @typing.overload
    def isSupported(self, arg1: java.time.temporal.TemporalField, /) -> bool: ...
    @typing.overload
    def isSupported(self, unit: java.time.temporal.TemporalUnit, /) -> bool: ...
    @typing.overload
    def minus(self, amount: java.time.temporal.TemporalAmount, /) -> ChronoZonedDateTime[_ChronoZonedDateTime__D]: ...
    @typing.overload
    def minus(self, amountToSubtract: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> ChronoZonedDateTime[_ChronoZonedDateTime__D]: ...
    @typing.overload
    def plus(self, amount: java.time.temporal.TemporalAmount, /) -> ChronoZonedDateTime[_ChronoZonedDateTime__D]: ...
    @typing.overload
    def plus(self, arg1: int | java.jlong | java.lang.Long, arg2: java.time.temporal.TemporalUnit, /) -> ChronoZonedDateTime[_ChronoZonedDateTime__D]: ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, query: java.time.temporal.TemporalQuery[_query__R], /) -> _query__R: ...
    def range(self, field: java.time.temporal.TemporalField, /) -> java.time.temporal.ValueRange: ...
    @staticmethod
    def timeLineOrder() -> java.util.Comparator[ChronoZonedDateTime[java.lang.Object]]: ...
    def toEpochSecond(self) -> int: ...
    def toInstant(self) -> java.time.Instant: ...
    def toLocalDate(self) -> _ChronoZonedDateTime__D: ...
    def toLocalDateTime(self) -> ChronoLocalDateTime[_ChronoZonedDateTime__D]: ...
    def toLocalTime(self) -> java.time.LocalTime: ...
    def toString(self) -> str: ...
    def withEarlierOffsetAtOverlap(self) -> ChronoZonedDateTime[_ChronoZonedDateTime__D]: ...
    def withLaterOffsetAtOverlap(self) -> ChronoZonedDateTime[_ChronoZonedDateTime__D]: ...
    def withZoneSameInstant(self, arg1: java.time.ZoneId, /) -> ChronoZonedDateTime[_ChronoZonedDateTime__D]: ...
    def withZoneSameLocal(self, arg1: java.time.ZoneId, /) -> ChronoZonedDateTime[_ChronoZonedDateTime__D]: ...
    @typing.overload
    def with_(self, adjuster: java.time.temporal.TemporalAdjuster, /) -> ChronoZonedDateTime[_ChronoZonedDateTime__D]: ...
    @typing.overload
    def with_(self, arg1: java.time.temporal.TemporalField, arg2: int | java.jlong | java.lang.Long, /) -> ChronoZonedDateTime[_ChronoZonedDateTime__D]: ...

class Chronology(java.lang.Comparable[Chronology]):
    def compareTo(self, arg1: Chronology, /) -> int: ...
    @typing.overload
    def date(self, arg1: java.time.temporal.TemporalAccessor, /) -> ChronoLocalDate: ...
    @typing.overload
    def date(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> ChronoLocalDate: ...
    @typing.overload
    def date(self, era: Era, yearOfEra: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> ChronoLocalDate: ...
    def dateEpochDay(self, arg1: int | java.jlong | java.lang.Long, /) -> ChronoLocalDate: ...
    @typing.overload
    def dateNow(self) -> ChronoLocalDate: ...
    @typing.overload
    def dateNow(self, clock: java.time.Clock, /) -> ChronoLocalDate: ...
    @typing.overload
    def dateNow(self, zone: java.time.ZoneId, /) -> ChronoLocalDate: ...
    @typing.overload
    def dateYearDay(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> ChronoLocalDate: ...
    @typing.overload
    def dateYearDay(self, era: Era, yearOfEra: int | java.jint | java.lang.Integer, dayOfYear: int | java.jint | java.lang.Integer, /) -> ChronoLocalDate: ...
    @typing.overload
    def epochSecond(self, prolepticYear: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, second: int | java.jint | java.lang.Integer, zoneOffset: java.time.ZoneOffset, /) -> int: ...
    @typing.overload
    def epochSecond(self, era: Era, yearOfEra: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, second: int | java.jint | java.lang.Integer, zoneOffset: java.time.ZoneOffset, /) -> int: ...
    def equals(self, arg1: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def eraOf(self, arg1: int | java.jint | java.lang.Integer, /) -> Era: ...
    def eras(self) -> java.util.List[Era]: ...
    @staticmethod
    def from_(temporal: java.time.temporal.TemporalAccessor, /) -> Chronology: ...
    @staticmethod
    def getAvailableChronologies() -> java.util.Set[Chronology]: ...
    def getCalendarType(self) -> str: ...
    def getDisplayName(self, style: java.time.format.TextStyle, locale: java.util.Locale, /) -> str: ...
    def getId(self) -> str: ...
    def hashCode(self) -> int: ...
    def isLeapYear(self, arg1: int | java.jlong | java.lang.Long, /) -> bool: ...
    def localDateTime(self, temporal: java.time.temporal.TemporalAccessor, /) -> ChronoLocalDateTime[ChronoLocalDate]: ...
    @staticmethod
    def of(id: str | java.lang.String, /) -> Chronology: ...
    @staticmethod
    def ofLocale(locale: java.util.Locale, /) -> Chronology: ...
    def period(self, years: int | java.jint | java.lang.Integer, months: int | java.jint | java.lang.Integer, days: int | java.jint | java.lang.Integer, /) -> ChronoPeriod: ...
    def prolepticYear(self, arg1: Era, arg2: int | java.jint | java.lang.Integer, /) -> int: ...
    def range(self, arg1: java.time.temporal.ChronoField, /) -> java.time.temporal.ValueRange: ...
    def resolveDate(self, arg1: java.util.Map[java.time.temporal.TemporalField, java.lang.Long], arg2: java.time.format.ResolverStyle, /) -> ChronoLocalDate: ...
    def toString(self) -> str: ...
    @typing.overload
    def zonedDateTime(self, temporal: java.time.temporal.TemporalAccessor, /) -> ChronoZonedDateTime[ChronoLocalDate]: ...
    @typing.overload
    def zonedDateTime(self, instant: java.time.Instant, zone: java.time.ZoneId, /) -> ChronoZonedDateTime[ChronoLocalDate]: ...

class Era(java.time.temporal.TemporalAccessor, java.time.temporal.TemporalAdjuster):
    def adjustInto(self, temporal: java.time.temporal.Temporal, /) -> java.time.temporal.Temporal: ...
    def get(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getDisplayName(self, style: java.time.format.TextStyle, locale: java.util.Locale, /) -> str: ...
    def getLong(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def getValue(self) -> int: ...
    def isSupported(self, field: java.time.temporal.TemporalField, /) -> bool: ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, query: java.time.temporal.TemporalQuery[_query__R], /) -> _query__R: ...
    def range(self, field: java.time.temporal.TemporalField, /) -> java.time.temporal.ValueRange: ...

class HijrahChronology(java.io.Serializable, AbstractChronology):
    INSTANCE: typing.ClassVar[HijrahChronology] = ...
    @typing.overload
    def date(self, temporal: java.time.temporal.TemporalAccessor, /) -> HijrahDate: ...
    @typing.overload
    def date(self, prolepticYear: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> HijrahDate: ...
    @typing.overload
    def date(self, era: Era, yearOfEra: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> HijrahDate: ...
    def dateEpochDay(self, epochDay: int | java.jlong | java.lang.Long, /) -> HijrahDate: ...
    @typing.overload
    def dateNow(self) -> HijrahDate: ...
    @typing.overload
    def dateNow(self, clock: java.time.Clock, /) -> HijrahDate: ...
    @typing.overload
    def dateNow(self, zone: java.time.ZoneId, /) -> HijrahDate: ...
    @typing.overload
    def dateYearDay(self, prolepticYear: int | java.jint | java.lang.Integer, dayOfYear: int | java.jint | java.lang.Integer, /) -> HijrahDate: ...
    @typing.overload
    def dateYearDay(self, era: Era, yearOfEra: int | java.jint | java.lang.Integer, dayOfYear: int | java.jint | java.lang.Integer, /) -> HijrahDate: ...
    def eraOf(self, eraValue: int | java.jint | java.lang.Integer, /) -> HijrahEra: ...
    def eras(self) -> java.util.List[Era]: ...
    def getCalendarType(self) -> str: ...
    def getId(self) -> str: ...
    def isLeapYear(self, prolepticYear: int | java.jlong | java.lang.Long, /) -> bool: ...
    def localDateTime(self, temporal: java.time.temporal.TemporalAccessor, /) -> ChronoLocalDateTime[HijrahDate]: ...
    def prolepticYear(self, era: Era, yearOfEra: int | java.jint | java.lang.Integer, /) -> int: ...
    def range(self, field: java.time.temporal.ChronoField, /) -> java.time.temporal.ValueRange: ...
    def resolveDate(self, fieldValues: java.util.Map[java.time.temporal.TemporalField, java.lang.Long], resolverStyle: java.time.format.ResolverStyle, /) -> HijrahDate: ...
    @typing.overload
    def zonedDateTime(self, temporal: java.time.temporal.TemporalAccessor, /) -> ChronoZonedDateTime[HijrahDate]: ...
    @typing.overload
    def zonedDateTime(self, instant: java.time.Instant, zone: java.time.ZoneId, /) -> ChronoZonedDateTime[HijrahDate]: ...

class HijrahDate(ChronoLocalDate, java.io.Serializable, java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster):
    def atTime(self, localTime: java.time.LocalTime, /) -> ChronoLocalDateTime[HijrahDate]: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def from_(temporal: java.time.temporal.TemporalAccessor, /) -> HijrahDate: ...
    def getChronology(self) -> HijrahChronology: ...
    def getEra(self) -> HijrahEra: ...
    def getLong(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def hashCode(self) -> int: ...
    def isLeapYear(self) -> bool: ...
    def lengthOfMonth(self) -> int: ...
    def lengthOfYear(self) -> int: ...
    @typing.overload
    def minus(self, amount: java.time.temporal.TemporalAmount, /) -> HijrahDate: ...
    @typing.overload
    def minus(self, amountToSubtract: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> HijrahDate: ...
    @typing.overload
    @staticmethod
    def now() -> HijrahDate: ...
    @typing.overload
    @staticmethod
    def now(clock: java.time.Clock, /) -> HijrahDate: ...
    @typing.overload
    @staticmethod
    def now(zone: java.time.ZoneId, /) -> HijrahDate: ...
    @staticmethod
    def of(prolepticYear: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> HijrahDate: ...
    @typing.overload
    def plus(self, amount: java.time.temporal.TemporalAmount, /) -> HijrahDate: ...
    @typing.overload
    def plus(self, amountToAdd: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> HijrahDate: ...
    def range(self, field: java.time.temporal.TemporalField, /) -> java.time.temporal.ValueRange: ...
    def toEpochDay(self) -> int: ...
    def toString(self) -> str: ...
    @typing.overload
    def until(self, endDate: ChronoLocalDate, /) -> ChronoPeriod: ...
    @typing.overload
    def until(self, endExclusive: java.time.temporal.Temporal, unit: java.time.temporal.TemporalUnit, /) -> int: ...
    def withVariant(self, chronology: HijrahChronology, /) -> HijrahDate: ...
    @typing.overload
    def with_(self, adjuster: java.time.temporal.TemporalAdjuster, /) -> HijrahDate: ...
    @typing.overload
    def with_(self, field: java.time.temporal.TemporalField, newValue: int | java.jlong | java.lang.Long, /) -> HijrahDate: ...

class HijrahEra(java.lang.Enum[HijrahEra], Era):
    AH: typing.ClassVar[HijrahEra] = ...
    def getDisplayName(self, style: java.time.format.TextStyle, locale: java.util.Locale, /) -> str: ...
    def getValue(self) -> int: ...
    @staticmethod
    def of(hijrahEra: int | java.jint | java.lang.Integer, /) -> HijrahEra: ...
    def range(self, field: java.time.temporal.TemporalField, /) -> java.time.temporal.ValueRange: ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> HijrahEra: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[HijrahEra]: ...

class IsoChronology(java.io.Serializable, AbstractChronology):
    INSTANCE: typing.ClassVar[IsoChronology] = ...
    @typing.overload
    def date(self, temporal: java.time.temporal.TemporalAccessor, /) -> java.time.LocalDate: ...
    @typing.overload
    def date(self, prolepticYear: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> java.time.LocalDate: ...
    @typing.overload
    def date(self, era: Era, yearOfEra: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> java.time.LocalDate: ...
    def dateEpochDay(self, epochDay: int | java.jlong | java.lang.Long, /) -> java.time.LocalDate: ...
    @typing.overload
    def dateNow(self) -> java.time.LocalDate: ...
    @typing.overload
    def dateNow(self, clock: java.time.Clock, /) -> java.time.LocalDate: ...
    @typing.overload
    def dateNow(self, zone: java.time.ZoneId, /) -> java.time.LocalDate: ...
    @typing.overload
    def dateYearDay(self, prolepticYear: int | java.jint | java.lang.Integer, dayOfYear: int | java.jint | java.lang.Integer, /) -> java.time.LocalDate: ...
    @typing.overload
    def dateYearDay(self, era: Era, yearOfEra: int | java.jint | java.lang.Integer, dayOfYear: int | java.jint | java.lang.Integer, /) -> java.time.LocalDate: ...
    def epochSecond(self, prolepticYear: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, hour: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, second: int | java.jint | java.lang.Integer, zoneOffset: java.time.ZoneOffset, /) -> int: ...
    def eraOf(self, eraValue: int | java.jint | java.lang.Integer, /) -> IsoEra: ...
    def eras(self) -> java.util.List[Era]: ...
    def getCalendarType(self) -> str: ...
    def getId(self) -> str: ...
    def isLeapYear(self, prolepticYear: int | java.jlong | java.lang.Long, /) -> bool: ...
    def localDateTime(self, temporal: java.time.temporal.TemporalAccessor, /) -> java.time.LocalDateTime: ...
    def period(self, years: int | java.jint | java.lang.Integer, months: int | java.jint | java.lang.Integer, days: int | java.jint | java.lang.Integer, /) -> java.time.Period: ...
    def prolepticYear(self, era: Era, yearOfEra: int | java.jint | java.lang.Integer, /) -> int: ...
    def range(self, field: java.time.temporal.ChronoField, /) -> java.time.temporal.ValueRange: ...
    def resolveDate(self, fieldValues: java.util.Map[java.time.temporal.TemporalField, java.lang.Long], resolverStyle: java.time.format.ResolverStyle, /) -> java.time.LocalDate: ...
    @typing.overload
    def zonedDateTime(self, temporal: java.time.temporal.TemporalAccessor, /) -> java.time.ZonedDateTime: ...
    @typing.overload
    def zonedDateTime(self, instant: java.time.Instant, zone: java.time.ZoneId, /) -> java.time.ZonedDateTime: ...

class IsoEra(java.lang.Enum[IsoEra], Era):
    BCE: typing.ClassVar[IsoEra] = ...
    CE: typing.ClassVar[IsoEra] = ...
    def getValue(self) -> int: ...
    @staticmethod
    def of(isoEra: int | java.jint | java.lang.Integer, /) -> IsoEra: ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> IsoEra: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[IsoEra]: ...

class JapaneseChronology(java.io.Serializable, AbstractChronology):
    INSTANCE: typing.ClassVar[JapaneseChronology] = ...
    @typing.overload
    def date(self, temporal: java.time.temporal.TemporalAccessor, /) -> JapaneseDate: ...
    @typing.overload
    def date(self, prolepticYear: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> JapaneseDate: ...
    @typing.overload
    def date(self, era: Era, yearOfEra: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> JapaneseDate: ...
    def dateEpochDay(self, epochDay: int | java.jlong | java.lang.Long, /) -> JapaneseDate: ...
    @typing.overload
    def dateNow(self) -> JapaneseDate: ...
    @typing.overload
    def dateNow(self, clock: java.time.Clock, /) -> JapaneseDate: ...
    @typing.overload
    def dateNow(self, zone: java.time.ZoneId, /) -> JapaneseDate: ...
    @typing.overload
    def dateYearDay(self, prolepticYear: int | java.jint | java.lang.Integer, dayOfYear: int | java.jint | java.lang.Integer, /) -> JapaneseDate: ...
    @typing.overload
    def dateYearDay(self, era: Era, yearOfEra: int | java.jint | java.lang.Integer, dayOfYear: int | java.jint | java.lang.Integer, /) -> JapaneseDate: ...
    def eraOf(self, eraValue: int | java.jint | java.lang.Integer, /) -> JapaneseEra: ...
    def eras(self) -> java.util.List[Era]: ...
    def getCalendarType(self) -> str: ...
    def getId(self) -> str: ...
    def isLeapYear(self, prolepticYear: int | java.jlong | java.lang.Long, /) -> bool: ...
    def localDateTime(self, temporal: java.time.temporal.TemporalAccessor, /) -> ChronoLocalDateTime[JapaneseDate]: ...
    def prolepticYear(self, era: Era, yearOfEra: int | java.jint | java.lang.Integer, /) -> int: ...
    def range(self, field: java.time.temporal.ChronoField, /) -> java.time.temporal.ValueRange: ...
    def resolveDate(self, fieldValues: java.util.Map[java.time.temporal.TemporalField, java.lang.Long], resolverStyle: java.time.format.ResolverStyle, /) -> JapaneseDate: ...
    @typing.overload
    def zonedDateTime(self, temporal: java.time.temporal.TemporalAccessor, /) -> ChronoZonedDateTime[JapaneseDate]: ...
    @typing.overload
    def zonedDateTime(self, instant: java.time.Instant, zone: java.time.ZoneId, /) -> ChronoZonedDateTime[JapaneseDate]: ...

class JapaneseDate(ChronoLocalDate, java.io.Serializable, java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster):
    def atTime(self, localTime: java.time.LocalTime, /) -> ChronoLocalDateTime[JapaneseDate]: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def from_(temporal: java.time.temporal.TemporalAccessor, /) -> JapaneseDate: ...
    def getChronology(self) -> JapaneseChronology: ...
    def getEra(self) -> JapaneseEra: ...
    def getLong(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def hashCode(self) -> int: ...
    def isSupported(self, field: java.time.temporal.TemporalField, /) -> bool: ...
    def lengthOfMonth(self) -> int: ...
    def lengthOfYear(self) -> int: ...
    @typing.overload
    def minus(self, amount: java.time.temporal.TemporalAmount, /) -> JapaneseDate: ...
    @typing.overload
    def minus(self, amountToAdd: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> JapaneseDate: ...
    @typing.overload
    @staticmethod
    def now() -> JapaneseDate: ...
    @typing.overload
    @staticmethod
    def now(clock: java.time.Clock, /) -> JapaneseDate: ...
    @typing.overload
    @staticmethod
    def now(zone: java.time.ZoneId, /) -> JapaneseDate: ...
    @typing.overload
    @staticmethod
    def of(prolepticYear: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> JapaneseDate: ...
    @typing.overload
    @staticmethod
    def of(era: JapaneseEra, yearOfEra: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> JapaneseDate: ...
    @typing.overload
    def plus(self, amount: java.time.temporal.TemporalAmount, /) -> JapaneseDate: ...
    @typing.overload
    def plus(self, amountToAdd: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> JapaneseDate: ...
    def range(self, field: java.time.temporal.TemporalField, /) -> java.time.temporal.ValueRange: ...
    def toEpochDay(self) -> int: ...
    def toString(self) -> str: ...
    @typing.overload
    def until(self, endDate: ChronoLocalDate, /) -> ChronoPeriod: ...
    @typing.overload
    def until(self, endExclusive: java.time.temporal.Temporal, unit: java.time.temporal.TemporalUnit, /) -> int: ...
    @typing.overload
    def with_(self, adjuster: java.time.temporal.TemporalAdjuster, /) -> JapaneseDate: ...
    @typing.overload
    def with_(self, field: java.time.temporal.TemporalField, newValue: int | java.jlong | java.lang.Long, /) -> JapaneseDate: ...

class JapaneseEra(Era, java.io.Serializable):
    HEISEI: typing.ClassVar[JapaneseEra] = ...
    MEIJI: typing.ClassVar[JapaneseEra] = ...
    REIWA: typing.ClassVar[JapaneseEra] = ...
    SHOWA: typing.ClassVar[JapaneseEra] = ...
    TAISHO: typing.ClassVar[JapaneseEra] = ...
    def getDisplayName(self, style: java.time.format.TextStyle, locale: java.util.Locale, /) -> str: ...
    def getValue(self) -> int: ...
    @staticmethod
    def of(japaneseEra: int | java.jint | java.lang.Integer, /) -> JapaneseEra: ...
    def range(self, field: java.time.temporal.TemporalField, /) -> java.time.temporal.ValueRange: ...
    def toString(self) -> str: ...
    @staticmethod
    def valueOf(japaneseEra: str | java.lang.String, /) -> JapaneseEra: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[JapaneseEra]: ...

class MinguoChronology(java.io.Serializable, AbstractChronology):
    INSTANCE: typing.ClassVar[MinguoChronology] = ...
    @typing.overload
    def date(self, temporal: java.time.temporal.TemporalAccessor, /) -> MinguoDate: ...
    @typing.overload
    def date(self, prolepticYear: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> MinguoDate: ...
    @typing.overload
    def date(self, era: Era, yearOfEra: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> MinguoDate: ...
    def dateEpochDay(self, epochDay: int | java.jlong | java.lang.Long, /) -> MinguoDate: ...
    @typing.overload
    def dateNow(self) -> MinguoDate: ...
    @typing.overload
    def dateNow(self, clock: java.time.Clock, /) -> MinguoDate: ...
    @typing.overload
    def dateNow(self, zone: java.time.ZoneId, /) -> MinguoDate: ...
    @typing.overload
    def dateYearDay(self, prolepticYear: int | java.jint | java.lang.Integer, dayOfYear: int | java.jint | java.lang.Integer, /) -> MinguoDate: ...
    @typing.overload
    def dateYearDay(self, era: Era, yearOfEra: int | java.jint | java.lang.Integer, dayOfYear: int | java.jint | java.lang.Integer, /) -> MinguoDate: ...
    def eraOf(self, eraValue: int | java.jint | java.lang.Integer, /) -> MinguoEra: ...
    def eras(self) -> java.util.List[Era]: ...
    def getCalendarType(self) -> str: ...
    def getId(self) -> str: ...
    def isLeapYear(self, prolepticYear: int | java.jlong | java.lang.Long, /) -> bool: ...
    def localDateTime(self, temporal: java.time.temporal.TemporalAccessor, /) -> ChronoLocalDateTime[MinguoDate]: ...
    def prolepticYear(self, era: Era, yearOfEra: int | java.jint | java.lang.Integer, /) -> int: ...
    def range(self, field: java.time.temporal.ChronoField, /) -> java.time.temporal.ValueRange: ...
    def resolveDate(self, fieldValues: java.util.Map[java.time.temporal.TemporalField, java.lang.Long], resolverStyle: java.time.format.ResolverStyle, /) -> MinguoDate: ...
    @typing.overload
    def zonedDateTime(self, temporal: java.time.temporal.TemporalAccessor, /) -> ChronoZonedDateTime[MinguoDate]: ...
    @typing.overload
    def zonedDateTime(self, instant: java.time.Instant, zone: java.time.ZoneId, /) -> ChronoZonedDateTime[MinguoDate]: ...

class MinguoDate(ChronoLocalDate, java.io.Serializable, java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster):
    def atTime(self, localTime: java.time.LocalTime, /) -> ChronoLocalDateTime[MinguoDate]: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def from_(temporal: java.time.temporal.TemporalAccessor, /) -> MinguoDate: ...
    def getChronology(self) -> MinguoChronology: ...
    def getEra(self) -> MinguoEra: ...
    def getLong(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def hashCode(self) -> int: ...
    def lengthOfMonth(self) -> int: ...
    @typing.overload
    def minus(self, amount: java.time.temporal.TemporalAmount, /) -> MinguoDate: ...
    @typing.overload
    def minus(self, amountToAdd: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> MinguoDate: ...
    @typing.overload
    @staticmethod
    def now() -> MinguoDate: ...
    @typing.overload
    @staticmethod
    def now(clock: java.time.Clock, /) -> MinguoDate: ...
    @typing.overload
    @staticmethod
    def now(zone: java.time.ZoneId, /) -> MinguoDate: ...
    @staticmethod
    def of(prolepticYear: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> MinguoDate: ...
    @typing.overload
    def plus(self, amount: java.time.temporal.TemporalAmount, /) -> MinguoDate: ...
    @typing.overload
    def plus(self, amountToAdd: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> MinguoDate: ...
    def range(self, field: java.time.temporal.TemporalField, /) -> java.time.temporal.ValueRange: ...
    def toEpochDay(self) -> int: ...
    def toString(self) -> str: ...
    @typing.overload
    def until(self, endDate: ChronoLocalDate, /) -> ChronoPeriod: ...
    @typing.overload
    def until(self, endExclusive: java.time.temporal.Temporal, unit: java.time.temporal.TemporalUnit, /) -> int: ...
    @typing.overload
    def with_(self, adjuster: java.time.temporal.TemporalAdjuster, /) -> MinguoDate: ...
    @typing.overload
    def with_(self, field: java.time.temporal.TemporalField, newValue: int | java.jlong | java.lang.Long, /) -> MinguoDate: ...

class MinguoEra(java.lang.Enum[MinguoEra], Era):
    BEFORE_ROC: typing.ClassVar[MinguoEra] = ...
    ROC: typing.ClassVar[MinguoEra] = ...
    def getDisplayName(self, style: java.time.format.TextStyle, locale: java.util.Locale, /) -> str: ...
    def getValue(self) -> int: ...
    @staticmethod
    def of(minguoEra: int | java.jint | java.lang.Integer, /) -> MinguoEra: ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> MinguoEra: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[MinguoEra]: ...

class ThaiBuddhistChronology(java.io.Serializable, AbstractChronology):
    INSTANCE: typing.ClassVar[ThaiBuddhistChronology] = ...
    @typing.overload
    def date(self, temporal: java.time.temporal.TemporalAccessor, /) -> ThaiBuddhistDate: ...
    @typing.overload
    def date(self, prolepticYear: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> ThaiBuddhistDate: ...
    @typing.overload
    def date(self, era: Era, yearOfEra: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> ThaiBuddhistDate: ...
    def dateEpochDay(self, epochDay: int | java.jlong | java.lang.Long, /) -> ThaiBuddhistDate: ...
    @typing.overload
    def dateNow(self) -> ThaiBuddhistDate: ...
    @typing.overload
    def dateNow(self, clock: java.time.Clock, /) -> ThaiBuddhistDate: ...
    @typing.overload
    def dateNow(self, zone: java.time.ZoneId, /) -> ThaiBuddhistDate: ...
    @typing.overload
    def dateYearDay(self, prolepticYear: int | java.jint | java.lang.Integer, dayOfYear: int | java.jint | java.lang.Integer, /) -> ThaiBuddhistDate: ...
    @typing.overload
    def dateYearDay(self, era: Era, yearOfEra: int | java.jint | java.lang.Integer, dayOfYear: int | java.jint | java.lang.Integer, /) -> ThaiBuddhistDate: ...
    def eraOf(self, eraValue: int | java.jint | java.lang.Integer, /) -> ThaiBuddhistEra: ...
    def eras(self) -> java.util.List[Era]: ...
    def getCalendarType(self) -> str: ...
    def getId(self) -> str: ...
    def isLeapYear(self, prolepticYear: int | java.jlong | java.lang.Long, /) -> bool: ...
    def localDateTime(self, temporal: java.time.temporal.TemporalAccessor, /) -> ChronoLocalDateTime[ThaiBuddhistDate]: ...
    def prolepticYear(self, era: Era, yearOfEra: int | java.jint | java.lang.Integer, /) -> int: ...
    def range(self, field: java.time.temporal.ChronoField, /) -> java.time.temporal.ValueRange: ...
    def resolveDate(self, fieldValues: java.util.Map[java.time.temporal.TemporalField, java.lang.Long], resolverStyle: java.time.format.ResolverStyle, /) -> ThaiBuddhistDate: ...
    @typing.overload
    def zonedDateTime(self, temporal: java.time.temporal.TemporalAccessor, /) -> ChronoZonedDateTime[ThaiBuddhistDate]: ...
    @typing.overload
    def zonedDateTime(self, instant: java.time.Instant, zone: java.time.ZoneId, /) -> ChronoZonedDateTime[ThaiBuddhistDate]: ...

class ThaiBuddhistDate(ChronoLocalDate, java.io.Serializable, java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster):
    def atTime(self, localTime: java.time.LocalTime, /) -> ChronoLocalDateTime[ThaiBuddhistDate]: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def from_(temporal: java.time.temporal.TemporalAccessor, /) -> ThaiBuddhistDate: ...
    def getChronology(self) -> ThaiBuddhistChronology: ...
    def getEra(self) -> ThaiBuddhistEra: ...
    def getLong(self, field: java.time.temporal.TemporalField, /) -> int: ...
    def hashCode(self) -> int: ...
    def lengthOfMonth(self) -> int: ...
    @typing.overload
    def minus(self, amount: java.time.temporal.TemporalAmount, /) -> ThaiBuddhistDate: ...
    @typing.overload
    def minus(self, amountToAdd: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> ThaiBuddhistDate: ...
    @typing.overload
    @staticmethod
    def now() -> ThaiBuddhistDate: ...
    @typing.overload
    @staticmethod
    def now(clock: java.time.Clock, /) -> ThaiBuddhistDate: ...
    @typing.overload
    @staticmethod
    def now(zone: java.time.ZoneId, /) -> ThaiBuddhistDate: ...
    @staticmethod
    def of(prolepticYear: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> ThaiBuddhistDate: ...
    @typing.overload
    def plus(self, amount: java.time.temporal.TemporalAmount, /) -> ThaiBuddhistDate: ...
    @typing.overload
    def plus(self, amountToAdd: int | java.jlong | java.lang.Long, unit: java.time.temporal.TemporalUnit, /) -> ThaiBuddhistDate: ...
    def range(self, field: java.time.temporal.TemporalField, /) -> java.time.temporal.ValueRange: ...
    def toEpochDay(self) -> int: ...
    def toString(self) -> str: ...
    @typing.overload
    def until(self, endDate: ChronoLocalDate, /) -> ChronoPeriod: ...
    @typing.overload
    def until(self, endExclusive: java.time.temporal.Temporal, unit: java.time.temporal.TemporalUnit, /) -> int: ...
    @typing.overload
    def with_(self, adjuster: java.time.temporal.TemporalAdjuster, /) -> ThaiBuddhistDate: ...
    @typing.overload
    def with_(self, field: java.time.temporal.TemporalField, newValue: int | java.jlong | java.lang.Long, /) -> ThaiBuddhistDate: ...

class ThaiBuddhistEra(java.lang.Enum[ThaiBuddhistEra], Era):
    BE: typing.ClassVar[ThaiBuddhistEra] = ...
    BEFORE_BE: typing.ClassVar[ThaiBuddhistEra] = ...
    def getDisplayName(self, style: java.time.format.TextStyle, locale: java.util.Locale, /) -> str: ...
    def getValue(self) -> int: ...
    @staticmethod
    def of(thaiBuddhistEra: int | java.jint | java.lang.Integer, /) -> ThaiBuddhistEra: ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> ThaiBuddhistEra: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[ThaiBuddhistEra]: ...



import typing

import android.os
import android.util
import java
import java.chaquopy
import java.lang
import java.util
import java.util.concurrent
import java.util.function

class HealthStats(java.lang.Object):
    def getDataType(self) -> str: ...
    def getMeasurement(self, key: int | java.jint | java.lang.Integer, /) -> int: ...
    def getMeasurementKeyAt(self, index: int | java.jint | java.lang.Integer, /) -> int: ...
    def getMeasurementKeyCount(self) -> int: ...
    def getMeasurements(self, key: int | java.jint | java.lang.Integer, /) -> java.util.Map[java.lang.String, java.lang.Long]: ...
    def getMeasurementsKeyAt(self, index: int | java.jint | java.lang.Integer, /) -> int: ...
    def getMeasurementsKeyCount(self) -> int: ...
    def getStats(self, key: int | java.jint | java.lang.Integer, /) -> java.util.Map[java.lang.String, HealthStats]: ...
    def getStatsKeyAt(self, index: int | java.jint | java.lang.Integer, /) -> int: ...
    def getStatsKeyCount(self) -> int: ...
    def getTimer(self, key: int | java.jint | java.lang.Integer, /) -> TimerStat: ...
    def getTimerCount(self, key: int | java.jint | java.lang.Integer, /) -> int: ...
    def getTimerKeyAt(self, index: int | java.jint | java.lang.Integer, /) -> int: ...
    def getTimerKeyCount(self) -> int: ...
    def getTimerTime(self, key: int | java.jint | java.lang.Integer, /) -> int: ...
    def getTimers(self, key: int | java.jint | java.lang.Integer, /) -> java.util.Map[java.lang.String, TimerStat]: ...
    def getTimersKeyAt(self, index: int | java.jint | java.lang.Integer, /) -> int: ...
    def getTimersKeyCount(self) -> int: ...
    def hasMeasurement(self, key: int | java.jint | java.lang.Integer, /) -> bool: ...
    def hasMeasurements(self, key: int | java.jint | java.lang.Integer, /) -> bool: ...
    def hasStats(self, key: int | java.jint | java.lang.Integer, /) -> bool: ...
    def hasTimer(self, key: int | java.jint | java.lang.Integer, /) -> bool: ...
    def hasTimers(self, key: int | java.jint | java.lang.Integer, /) -> bool: ...

class PackageHealthStats(java.lang.Object):
    MEASUREMENTS_WAKEUP_ALARMS_COUNT: typing.ClassVar[int] = ...
    STATS_SERVICES: typing.ClassVar[int] = ...

class PidHealthStats(java.lang.Object):
    MEASUREMENT_WAKE_NESTING_COUNT: typing.ClassVar[int] = ...
    MEASUREMENT_WAKE_START_MS: typing.ClassVar[int] = ...
    MEASUREMENT_WAKE_SUM_MS: typing.ClassVar[int] = ...

class ProcessHealthStats(java.lang.Object):
    MEASUREMENT_ANR_COUNT: typing.ClassVar[int] = ...
    MEASUREMENT_CRASHES_COUNT: typing.ClassVar[int] = ...
    MEASUREMENT_FOREGROUND_MS: typing.ClassVar[int] = ...
    MEASUREMENT_STARTS_COUNT: typing.ClassVar[int] = ...
    MEASUREMENT_SYSTEM_TIME_MS: typing.ClassVar[int] = ...
    MEASUREMENT_USER_TIME_MS: typing.ClassVar[int] = ...

class ServiceHealthStats(java.lang.Object):
    MEASUREMENT_LAUNCH_COUNT: typing.ClassVar[int] = ...
    MEASUREMENT_START_SERVICE_COUNT: typing.ClassVar[int] = ...

class SystemHealthManager(java.lang.Object):
    def getCpuHeadroom(self, params: android.os.CpuHeadroomParams, /) -> float: ...
    def getCpuHeadroomCalculationWindowRange(self) -> android.util.Pair[java.lang.Integer, java.lang.Integer]: ...
    def getCpuHeadroomMinIntervalMillis(self) -> int: ...
    def getGpuHeadroom(self, params: android.os.GpuHeadroomParams, /) -> float: ...
    def getGpuHeadroomCalculationWindowRange(self) -> android.util.Pair[java.lang.Integer, java.lang.Integer]: ...
    def getGpuHeadroomMinIntervalMillis(self) -> int: ...
    def getMaxCpuHeadroomTidsSize(self) -> int: ...
    def getPowerMonitorReadings(self, powerMonitors: java.util.List[android.os.PowerMonitor], executor: java.util.concurrent.Executor, onResult: android.os.OutcomeReceiver[android.os.PowerMonitorReadings, java.lang.RuntimeException], /) -> None: ...
    def getSupportedPowerMonitors(self, executor: java.util.concurrent.Executor, onResult: java.util.function.Consumer[java.util.List[android.os.PowerMonitor]], /) -> None: ...
    def takeMyUidSnapshot(self) -> HealthStats: ...
    def takeUidSnapshot(self, uid: int | java.jint | java.lang.Integer, /) -> HealthStats: ...
    def takeUidSnapshots(self, uids: java.chaquopy.JavaArrayJInt, /) -> java.chaquopy.JavaArray[HealthStats]: ...

class TimerStat(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TimerStat]] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, in_: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, count: int | java.jint | java.lang.Integer, time: int | java.jlong | java.lang.Long, /) -> None: ...
    def describeContents(self) -> int: ...
    def getCount(self) -> int: ...
    def getTime(self) -> int: ...
    def setCount(self, count: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTime(self, time: int | java.jlong | java.lang.Long, /) -> None: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class UidHealthStats(java.lang.Object):
    MEASUREMENT_BLUETOOTH_IDLE_MS: typing.ClassVar[int] = ...
    MEASUREMENT_BLUETOOTH_POWER_MAMS: typing.ClassVar[int] = ...
    MEASUREMENT_BLUETOOTH_RX_BYTES: typing.ClassVar[int] = ...
    MEASUREMENT_BLUETOOTH_RX_MS: typing.ClassVar[int] = ...
    MEASUREMENT_BLUETOOTH_RX_PACKETS: typing.ClassVar[int] = ...
    MEASUREMENT_BLUETOOTH_TX_BYTES: typing.ClassVar[int] = ...
    MEASUREMENT_BLUETOOTH_TX_MS: typing.ClassVar[int] = ...
    MEASUREMENT_BLUETOOTH_TX_PACKETS: typing.ClassVar[int] = ...
    MEASUREMENT_BUTTON_USER_ACTIVITY_COUNT: typing.ClassVar[int] = ...
    MEASUREMENT_CPU_POWER_MAMS: typing.ClassVar[int] = ...
    MEASUREMENT_MOBILE_IDLE_MS: typing.ClassVar[int] = ...
    MEASUREMENT_MOBILE_POWER_MAMS: typing.ClassVar[int] = ...
    MEASUREMENT_MOBILE_RX_BYTES: typing.ClassVar[int] = ...
    MEASUREMENT_MOBILE_RX_MS: typing.ClassVar[int] = ...
    MEASUREMENT_MOBILE_RX_PACKETS: typing.ClassVar[int] = ...
    MEASUREMENT_MOBILE_TX_BYTES: typing.ClassVar[int] = ...
    MEASUREMENT_MOBILE_TX_MS: typing.ClassVar[int] = ...
    MEASUREMENT_MOBILE_TX_PACKETS: typing.ClassVar[int] = ...
    MEASUREMENT_OTHER_USER_ACTIVITY_COUNT: typing.ClassVar[int] = ...
    MEASUREMENT_REALTIME_BATTERY_MS: typing.ClassVar[int] = ...
    MEASUREMENT_REALTIME_SCREEN_OFF_BATTERY_MS: typing.ClassVar[int] = ...
    MEASUREMENT_SYSTEM_CPU_TIME_MS: typing.ClassVar[int] = ...
    MEASUREMENT_TOUCH_USER_ACTIVITY_COUNT: typing.ClassVar[int] = ...
    MEASUREMENT_UPTIME_BATTERY_MS: typing.ClassVar[int] = ...
    MEASUREMENT_UPTIME_SCREEN_OFF_BATTERY_MS: typing.ClassVar[int] = ...
    MEASUREMENT_USER_CPU_TIME_MS: typing.ClassVar[int] = ...
    MEASUREMENT_WIFI_FULL_LOCK_MS: typing.ClassVar[int] = ...
    MEASUREMENT_WIFI_IDLE_MS: typing.ClassVar[int] = ...
    MEASUREMENT_WIFI_MULTICAST_MS: typing.ClassVar[int] = ...
    MEASUREMENT_WIFI_POWER_MAMS: typing.ClassVar[int] = ...
    MEASUREMENT_WIFI_RUNNING_MS: typing.ClassVar[int] = ...
    MEASUREMENT_WIFI_RX_BYTES: typing.ClassVar[int] = ...
    MEASUREMENT_WIFI_RX_MS: typing.ClassVar[int] = ...
    MEASUREMENT_WIFI_RX_PACKETS: typing.ClassVar[int] = ...
    MEASUREMENT_WIFI_TX_BYTES: typing.ClassVar[int] = ...
    MEASUREMENT_WIFI_TX_MS: typing.ClassVar[int] = ...
    MEASUREMENT_WIFI_TX_PACKETS: typing.ClassVar[int] = ...
    STATS_PACKAGES: typing.ClassVar[int] = ...
    STATS_PIDS: typing.ClassVar[int] = ...
    STATS_PROCESSES: typing.ClassVar[int] = ...
    TIMERS_JOBS: typing.ClassVar[int] = ...
    TIMERS_SENSORS: typing.ClassVar[int] = ...
    TIMERS_SYNCS: typing.ClassVar[int] = ...
    TIMERS_WAKELOCKS_DRAW: typing.ClassVar[int] = ...
    TIMERS_WAKELOCKS_FULL: typing.ClassVar[int] = ...
    TIMERS_WAKELOCKS_PARTIAL: typing.ClassVar[int] = ...
    TIMERS_WAKELOCKS_WINDOW: typing.ClassVar[int] = ...
    TIMER_AUDIO: typing.ClassVar[int] = ...
    TIMER_BLUETOOTH_SCAN: typing.ClassVar[int] = ...
    TIMER_CAMERA: typing.ClassVar[int] = ...
    TIMER_FLASHLIGHT: typing.ClassVar[int] = ...
    TIMER_FOREGROUND_ACTIVITY: typing.ClassVar[int] = ...
    TIMER_GPS_SENSOR: typing.ClassVar[int] = ...
    TIMER_MOBILE_RADIO_ACTIVE: typing.ClassVar[int] = ...
    TIMER_PROCESS_STATE_BACKGROUND_MS: typing.ClassVar[int] = ...
    TIMER_PROCESS_STATE_CACHED_MS: typing.ClassVar[int] = ...
    TIMER_PROCESS_STATE_FOREGROUND_MS: typing.ClassVar[int] = ...
    TIMER_PROCESS_STATE_FOREGROUND_SERVICE_MS: typing.ClassVar[int] = ...
    TIMER_PROCESS_STATE_TOP_MS: typing.ClassVar[int] = ...
    TIMER_PROCESS_STATE_TOP_SLEEPING_MS: typing.ClassVar[int] = ...
    TIMER_VIBRATOR: typing.ClassVar[int] = ...
    TIMER_VIDEO: typing.ClassVar[int] = ...
    TIMER_WIFI_SCAN: typing.ClassVar[int] = ...



import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.math
import java.util

class Annotation(java.lang.Object):
    def __init__(self, value: java.lang.Object | int | bool | float | str, /) -> None: ...
    def getValue(self) -> java.lang.Object: ...
    def toString(self) -> str: ...

class AttributedCharacterIterator(CharacterIterator):
    def getAllAttributeKeys(self) -> java.util.Set[AttributedCharacterIterator.Attribute]: ...
    def getAttribute(self, arg1: AttributedCharacterIterator.Attribute, /) -> java.lang.Object: ...
    def getAttributes(self) -> java.util.Map[AttributedCharacterIterator.Attribute, java.lang.Object]: ...
    @typing.overload
    def getRunLimit(self) -> int: ...
    @typing.overload
    def getRunLimit(self, arg1: AttributedCharacterIterator.Attribute, /) -> int: ...
    @typing.overload
    def getRunLimit(self, arg1: java.util.Set[AttributedCharacterIterator.Attribute], /) -> int: ...
    @typing.overload
    def getRunStart(self) -> int: ...
    @typing.overload
    def getRunStart(self, arg1: AttributedCharacterIterator.Attribute, /) -> int: ...
    @typing.overload
    def getRunStart(self, arg1: java.util.Set[AttributedCharacterIterator.Attribute], /) -> int: ...

    class Attribute(java.io.Serializable):
        INPUT_METHOD_SEGMENT: typing.ClassVar[AttributedCharacterIterator.Attribute] = ...
        LANGUAGE: typing.ClassVar[AttributedCharacterIterator.Attribute] = ...
        READING: typing.ClassVar[AttributedCharacterIterator.Attribute] = ...
        def __init__(self, name: str | java.lang.String, /) -> None: ...
        def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getName(self) -> str: ...
        def hashCode(self) -> int: ...
        def readResolve(self) -> java.lang.Object: ...
        def toString(self) -> str: ...

class AttributedString(java.lang.Object):
    @typing.overload
    def __init__(self, text: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, text: AttributedCharacterIterator, /) -> None: ...
    @typing.overload
    def __init__(self, text: str | java.lang.String, attributes: java.util.Map[AttributedCharacterIterator.Attribute, java.lang.Object], /) -> None: ...
    @typing.overload
    def __init__(self, text: AttributedCharacterIterator, beginIndex: int | java.jint | java.lang.Integer, endIndex: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, text: AttributedCharacterIterator, beginIndex: int | java.jint | java.lang.Integer, endIndex: int | java.jint | java.lang.Integer, attributes: java.chaquopy.JavaArray[AttributedCharacterIterator.Attribute], /) -> None: ...
    @typing.overload
    def addAttribute(self, attribute: AttributedCharacterIterator.Attribute, value: java.lang.Object | int | bool | float | str, /) -> None: ...
    @typing.overload
    def addAttribute(self, attribute: AttributedCharacterIterator.Attribute, value: java.lang.Object | int | bool | float | str, beginIndex: int | java.jint | java.lang.Integer, endIndex: int | java.jint | java.lang.Integer, /) -> None: ...
    def addAttributes(self, attributes: java.util.Map[AttributedCharacterIterator.Attribute, java.lang.Object], beginIndex: int | java.jint | java.lang.Integer, endIndex: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def getIterator(self) -> AttributedCharacterIterator: ...
    @typing.overload
    def getIterator(self, attributes: java.chaquopy.JavaArray[AttributedCharacterIterator.Attribute], /) -> AttributedCharacterIterator: ...
    @typing.overload
    def getIterator(self, attributes: java.chaquopy.JavaArray[AttributedCharacterIterator.Attribute], beginIndex: int | java.jint | java.lang.Integer, endIndex: int | java.jint | java.lang.Integer, /) -> AttributedCharacterIterator: ...

class Bidi(java.lang.Object):
    DIRECTION_DEFAULT_LEFT_TO_RIGHT: typing.ClassVar[int] = ...
    DIRECTION_DEFAULT_RIGHT_TO_LEFT: typing.ClassVar[int] = ...
    DIRECTION_LEFT_TO_RIGHT: typing.ClassVar[int] = ...
    DIRECTION_RIGHT_TO_LEFT: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, paragraph: AttributedCharacterIterator, /) -> None: ...
    @typing.overload
    def __init__(self, paragraph: str | java.lang.String, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, text: java.chaquopy.JavaArrayJChar, textStart: int | java.jint | java.lang.Integer, embeddings: java.chaquopy.JavaArrayJByte, embStart: int | java.jint | java.lang.Integer, paragraphLength: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def baseIsLeftToRight(self) -> bool: ...
    def createLineBidi(self, lineStart: int | java.jint | java.lang.Integer, lineLimit: int | java.jint | java.lang.Integer, /) -> Bidi: ...
    def getBaseLevel(self) -> int: ...
    def getLength(self) -> int: ...
    def getLevelAt(self, offset: int | java.jint | java.lang.Integer, /) -> int: ...
    def getRunCount(self) -> int: ...
    def getRunLevel(self, run: int | java.jint | java.lang.Integer, /) -> int: ...
    def getRunLimit(self, run: int | java.jint | java.lang.Integer, /) -> int: ...
    def getRunStart(self, run: int | java.jint | java.lang.Integer, /) -> int: ...
    def isLeftToRight(self) -> bool: ...
    def isMixed(self) -> bool: ...
    def isRightToLeft(self) -> bool: ...
    @staticmethod
    def reorderVisually(levels: java.chaquopy.JavaArrayJByte, levelStart: int | java.jint | java.lang.Integer, objects: java.chaquopy.JavaArray[java.lang.Object], objectStart: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def requiresBidi(text: java.chaquopy.JavaArrayJChar, start: int | java.jint | java.lang.Integer, limit: int | java.jint | java.lang.Integer, /) -> bool: ...
    def toString(self) -> str: ...

class BreakIterator(java.lang.Cloneable):
    DONE: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def clone(self) -> java.lang.Object: ...
    def current(self) -> int: ...
    def first(self) -> int: ...
    def following(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getAvailableLocales() -> java.chaquopy.JavaArray[java.util.Locale]: ...
    @typing.overload
    @staticmethod
    def getCharacterInstance() -> BreakIterator: ...
    @typing.overload
    @staticmethod
    def getCharacterInstance(locale: java.util.Locale, /) -> BreakIterator: ...
    @typing.overload
    @staticmethod
    def getLineInstance() -> BreakIterator: ...
    @typing.overload
    @staticmethod
    def getLineInstance(locale: java.util.Locale, /) -> BreakIterator: ...
    @typing.overload
    @staticmethod
    def getSentenceInstance() -> BreakIterator: ...
    @typing.overload
    @staticmethod
    def getSentenceInstance(locale: java.util.Locale, /) -> BreakIterator: ...
    def getText(self) -> CharacterIterator: ...
    @typing.overload
    @staticmethod
    def getWordInstance() -> BreakIterator: ...
    @typing.overload
    @staticmethod
    def getWordInstance(locale: java.util.Locale, /) -> BreakIterator: ...
    def isBoundary(self, offset: int | java.jint | java.lang.Integer, /) -> bool: ...
    def last(self) -> int: ...
    @typing.overload
    def next(self) -> int: ...
    @typing.overload
    def next(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def preceding(self, offset: int | java.jint | java.lang.Integer, /) -> int: ...
    def previous(self) -> int: ...
    @typing.overload
    def setText(self, newText: str | java.lang.String, /) -> None: ...
    @typing.overload
    def setText(self, arg1: CharacterIterator, /) -> None: ...

class CharacterIterator(java.lang.Cloneable):
    DONE: typing.ClassVar[str] = ...
    def clone(self) -> java.lang.Object: ...
    def current(self) -> str: ...
    def first(self) -> str: ...
    def getBeginIndex(self) -> int: ...
    def getEndIndex(self) -> int: ...
    def getIndex(self) -> int: ...
    def last(self) -> str: ...
    def next(self) -> str: ...
    def previous(self) -> str: ...
    def setIndex(self, arg1: int | java.jint | java.lang.Integer, /) -> str: ...

class ChoiceFormat(NumberFormat):
    @typing.overload
    def __init__(self, newPattern: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, limits: java.chaquopy.JavaArrayJDouble, formats: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def applyPattern(self, newPattern: str | java.lang.String, /) -> None: ...
    def clone(self) -> java.lang.Object: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @typing.overload
    def format(self, number: float | java.jdouble | java.lang.Double, toAppendTo: java.lang.StringBuffer, status: FieldPosition, /) -> java.lang.StringBuffer: ...
    @typing.overload
    def format(self, number: int | java.jlong | java.lang.Long, toAppendTo: java.lang.StringBuffer, status: FieldPosition, /) -> java.lang.StringBuffer: ...
    def getFormats(self) -> java.chaquopy.JavaArray[java.lang.Object]: ...
    def getLimits(self) -> java.chaquopy.JavaArrayJDouble: ...
    def hashCode(self) -> int: ...
    @typing.overload
    @staticmethod
    def nextDouble(d: float | java.jdouble | java.lang.Double, /) -> float: ...
    @typing.overload
    @staticmethod
    def nextDouble(d: float | java.jdouble | java.lang.Double, positive: bool | java.jboolean | java.lang.Boolean, /) -> float: ...
    def parse(self, text: str | java.lang.String, status: ParsePosition, /) -> java.lang.Number: ...
    @staticmethod
    def previousDouble(d: float | java.jdouble | java.lang.Double, /) -> float: ...
    def setChoices(self, limits: java.chaquopy.JavaArrayJDouble, formats: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def toPattern(self) -> str: ...

class CollationElementIterator(java.lang.Object):
    NULLORDER: typing.ClassVar[int] = ...
    def getMaxExpansion(self, order: int | java.jint | java.lang.Integer, /) -> int: ...
    def getOffset(self) -> int: ...
    def next(self) -> int: ...
    def previous(self) -> int: ...
    @staticmethod
    def primaryOrder(order: int | java.jint | java.lang.Integer, /) -> int: ...
    def reset(self) -> None: ...
    @staticmethod
    def secondaryOrder(order: int | java.jint | java.lang.Integer, /) -> int: ...
    def setOffset(self, newOffset: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setText(self, source: str | java.lang.String, /) -> None: ...
    @typing.overload
    def setText(self, source: CharacterIterator, /) -> None: ...
    @staticmethod
    def tertiaryOrder(order: int | java.jint | java.lang.Integer, /) -> int: ...

class CollationKey(java.lang.Comparable[CollationKey]):
    def __init__(self, source: str | java.lang.String, /) -> None: ...
    def compareTo(self, arg1: CollationKey, /) -> int: ...
    def getSourceString(self) -> str: ...
    def toByteArray(self) -> java.chaquopy.JavaArrayJByte: ...

class Collator(java.lang.Cloneable, java.util.Comparator[java.lang.Object]):
    CANONICAL_DECOMPOSITION: typing.ClassVar[int] = ...
    FULL_DECOMPOSITION: typing.ClassVar[int] = ...
    IDENTICAL: typing.ClassVar[int] = ...
    NO_DECOMPOSITION: typing.ClassVar[int] = ...
    PRIMARY: typing.ClassVar[int] = ...
    SECONDARY: typing.ClassVar[int] = ...
    TERTIARY: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def clone(self) -> java.lang.Object: ...
    @typing.overload
    def compare(self, o1: java.lang.Object | int | bool | float | str, o2: java.lang.Object | int | bool | float | str, /) -> int: ...
    @typing.overload
    def compare(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> int: ...
    @typing.overload
    def equals(self, that: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @typing.overload
    def equals(self, source: str | java.lang.String, target: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def getAvailableLocales() -> java.chaquopy.JavaArray[java.util.Locale]: ...
    def getCollationKey(self, arg1: str | java.lang.String, /) -> CollationKey: ...
    def getDecomposition(self) -> int: ...
    @typing.overload
    @staticmethod
    def getInstance() -> Collator: ...
    @typing.overload
    @staticmethod
    def getInstance(desiredLocale: java.util.Locale, /) -> Collator: ...
    def getStrength(self) -> int: ...
    def hashCode(self) -> int: ...
    def setDecomposition(self, decompositionMode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setStrength(self, newStrength: int | java.jint | java.lang.Integer, /) -> None: ...

class DateFormat(Format):
    AM_PM_FIELD: typing.ClassVar[int] = ...
    DATE_FIELD: typing.ClassVar[int] = ...
    DAY_OF_WEEK_FIELD: typing.ClassVar[int] = ...
    DAY_OF_WEEK_IN_MONTH_FIELD: typing.ClassVar[int] = ...
    DAY_OF_YEAR_FIELD: typing.ClassVar[int] = ...
    DEFAULT: typing.ClassVar[int] = ...
    ERA_FIELD: typing.ClassVar[int] = ...
    FULL: typing.ClassVar[int] = ...
    HOUR0_FIELD: typing.ClassVar[int] = ...
    HOUR1_FIELD: typing.ClassVar[int] = ...
    HOUR_OF_DAY0_FIELD: typing.ClassVar[int] = ...
    HOUR_OF_DAY1_FIELD: typing.ClassVar[int] = ...
    LONG: typing.ClassVar[int] = ...
    MEDIUM: typing.ClassVar[int] = ...
    MILLISECOND_FIELD: typing.ClassVar[int] = ...
    MINUTE_FIELD: typing.ClassVar[int] = ...
    MONTH_FIELD: typing.ClassVar[int] = ...
    SECOND_FIELD: typing.ClassVar[int] = ...
    SHORT: typing.ClassVar[int] = ...
    TIMEZONE_FIELD: typing.ClassVar[int] = ...
    WEEK_OF_MONTH_FIELD: typing.ClassVar[int] = ...
    WEEK_OF_YEAR_FIELD: typing.ClassVar[int] = ...
    YEAR_FIELD: typing.ClassVar[int] = ...
    calendar: java.util.Calendar = ...
    numberFormat: NumberFormat = ...
    def __init__(self) -> None: ...
    def clone(self) -> java.lang.Object: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @typing.overload
    def format(self, date: java.util.Date, /) -> str: ...
    @typing.overload
    def format(self, obj: java.lang.Object | int | bool | float | str, toAppendTo: java.lang.StringBuffer, fieldPosition: FieldPosition, /) -> java.lang.StringBuffer: ...
    @typing.overload
    def format(self, arg1: java.util.Date, arg2: java.lang.StringBuffer, arg3: FieldPosition, /) -> java.lang.StringBuffer: ...
    @staticmethod
    def getAvailableLocales() -> java.chaquopy.JavaArray[java.util.Locale]: ...
    def getCalendar(self) -> java.util.Calendar: ...
    @typing.overload
    @staticmethod
    def getDateInstance() -> DateFormat: ...
    @typing.overload
    @staticmethod
    def getDateInstance(style: int | java.jint | java.lang.Integer, /) -> DateFormat: ...
    @typing.overload
    @staticmethod
    def getDateInstance(style: int | java.jint | java.lang.Integer, aLocale: java.util.Locale, /) -> DateFormat: ...
    @typing.overload
    @staticmethod
    def getDateTimeInstance() -> DateFormat: ...
    @typing.overload
    @staticmethod
    def getDateTimeInstance(dateStyle: int | java.jint | java.lang.Integer, timeStyle: int | java.jint | java.lang.Integer, /) -> DateFormat: ...
    @typing.overload
    @staticmethod
    def getDateTimeInstance(dateStyle: int | java.jint | java.lang.Integer, timeStyle: int | java.jint | java.lang.Integer, aLocale: java.util.Locale, /) -> DateFormat: ...
    @staticmethod
    def getInstance() -> DateFormat: ...
    def getNumberFormat(self) -> NumberFormat: ...
    @typing.overload
    @staticmethod
    def getTimeInstance() -> DateFormat: ...
    @typing.overload
    @staticmethod
    def getTimeInstance(style: int | java.jint | java.lang.Integer, /) -> DateFormat: ...
    @typing.overload
    @staticmethod
    def getTimeInstance(style: int | java.jint | java.lang.Integer, aLocale: java.util.Locale, /) -> DateFormat: ...
    def getTimeZone(self) -> java.util.TimeZone: ...
    def hashCode(self) -> int: ...
    def isLenient(self) -> bool: ...
    @typing.overload
    def parse(self, source: str | java.lang.String, /) -> java.util.Date: ...
    @typing.overload
    def parse(self, arg1: str | java.lang.String, arg2: ParsePosition, /) -> java.util.Date: ...
    def parseObject(self, source: str | java.lang.String, pos: ParsePosition, /) -> java.lang.Object: ...
    def setCalendar(self, newCalendar: java.util.Calendar, /) -> None: ...
    def setLenient(self, lenient: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setNumberFormat(self, newNumberFormat: NumberFormat, /) -> None: ...
    def setTimeZone(self, zone: java.util.TimeZone, /) -> None: ...

    class Field(Format.Field):
        AM_PM: typing.ClassVar[DateFormat.Field] = ...
        DAY_OF_MONTH: typing.ClassVar[DateFormat.Field] = ...
        DAY_OF_WEEK: typing.ClassVar[DateFormat.Field] = ...
        DAY_OF_WEEK_IN_MONTH: typing.ClassVar[DateFormat.Field] = ...
        DAY_OF_YEAR: typing.ClassVar[DateFormat.Field] = ...
        ERA: typing.ClassVar[DateFormat.Field] = ...
        HOUR0: typing.ClassVar[DateFormat.Field] = ...
        HOUR1: typing.ClassVar[DateFormat.Field] = ...
        HOUR_OF_DAY0: typing.ClassVar[DateFormat.Field] = ...
        HOUR_OF_DAY1: typing.ClassVar[DateFormat.Field] = ...
        MILLISECOND: typing.ClassVar[DateFormat.Field] = ...
        MINUTE: typing.ClassVar[DateFormat.Field] = ...
        MONTH: typing.ClassVar[DateFormat.Field] = ...
        SECOND: typing.ClassVar[DateFormat.Field] = ...
        TIME_ZONE: typing.ClassVar[DateFormat.Field] = ...
        WEEK_OF_MONTH: typing.ClassVar[DateFormat.Field] = ...
        WEEK_OF_YEAR: typing.ClassVar[DateFormat.Field] = ...
        YEAR: typing.ClassVar[DateFormat.Field] = ...
        def __init__(self, name: str | java.lang.String, calendarField: int | java.jint | java.lang.Integer, /) -> None: ...
        def getCalendarField(self) -> int: ...
        @staticmethod
        def ofCalendarField(calendarField: int | java.jint | java.lang.Integer, /) -> DateFormat.Field: ...
        def readResolve(self) -> java.lang.Object: ...

class DateFormatSymbols(java.io.Serializable, java.lang.Cloneable):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, locale: java.util.Locale, /) -> None: ...
    def clone(self) -> java.lang.Object: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAmPmStrings(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    @staticmethod
    def getAvailableLocales() -> java.chaquopy.JavaArray[java.util.Locale]: ...
    def getEras(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    @typing.overload
    @staticmethod
    def getInstance() -> DateFormatSymbols: ...
    @typing.overload
    @staticmethod
    def getInstance(locale: java.util.Locale, /) -> DateFormatSymbols: ...
    def getLocalPatternChars(self) -> str: ...
    def getMonths(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getShortMonths(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getShortWeekdays(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getWeekdays(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getZoneStrings(self) -> java.chaquopy.JavaArray[java.chaquopy.JavaArray[java.lang.String]]: ...
    def hashCode(self) -> int: ...
    def setAmPmStrings(self, newAmpms: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def setEras(self, newEras: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def setLocalPatternChars(self, newLocalPatternChars: str | java.lang.String, /) -> None: ...
    def setMonths(self, newMonths: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def setShortMonths(self, newShortMonths: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def setShortWeekdays(self, newShortWeekdays: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def setWeekdays(self, newWeekdays: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def setZoneStrings(self, newZoneStrings: java.chaquopy.JavaArray[java.chaquopy.JavaArray[java.lang.String]], /) -> None: ...

class DecimalFormat(NumberFormat):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, pattern: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, pattern: str | java.lang.String, symbols: DecimalFormatSymbols, /) -> None: ...
    def applyLocalizedPattern(self, pattern: str | java.lang.String, /) -> None: ...
    def applyPattern(self, pattern: str | java.lang.String, /) -> None: ...
    def clone(self) -> java.lang.Object: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @typing.overload
    def format(self, number: float | java.jdouble | java.lang.Double, result: java.lang.StringBuffer, fieldPosition: FieldPosition, /) -> java.lang.StringBuffer: ...
    @typing.overload
    def format(self, number: int | java.jlong | java.lang.Long, result: java.lang.StringBuffer, fieldPosition: FieldPosition, /) -> java.lang.StringBuffer: ...
    @typing.overload
    def format(self, number: java.lang.Object | int | bool | float | str, toAppendTo: java.lang.StringBuffer, pos: FieldPosition, /) -> java.lang.StringBuffer: ...
    def formatToCharacterIterator(self, obj: java.lang.Object | int | bool | float | str, /) -> AttributedCharacterIterator: ...
    def getCurrency(self) -> java.util.Currency: ...
    def getDecimalFormatSymbols(self) -> DecimalFormatSymbols: ...
    def getGroupingSize(self) -> int: ...
    def getMaximumFractionDigits(self) -> int: ...
    def getMaximumIntegerDigits(self) -> int: ...
    def getMinimumFractionDigits(self) -> int: ...
    def getMinimumIntegerDigits(self) -> int: ...
    def getMultiplier(self) -> int: ...
    def getNegativePrefix(self) -> str: ...
    def getNegativeSuffix(self) -> str: ...
    def getPositivePrefix(self) -> str: ...
    def getPositiveSuffix(self) -> str: ...
    def getRoundingMode(self) -> java.math.RoundingMode: ...
    def hashCode(self) -> int: ...
    def isDecimalSeparatorAlwaysShown(self) -> bool: ...
    def isGroupingUsed(self) -> bool: ...
    def isParseBigDecimal(self) -> bool: ...
    def isParseIntegerOnly(self) -> bool: ...
    def parse(self, text: str | java.lang.String, pos: ParsePosition, /) -> java.lang.Number: ...
    def setCurrency(self, currency: java.util.Currency, /) -> None: ...
    def setDecimalFormatSymbols(self, newSymbols: DecimalFormatSymbols, /) -> None: ...
    def setDecimalSeparatorAlwaysShown(self, newValue: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setGroupingSize(self, newValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def setGroupingUsed(self, newValue: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setMaximumFractionDigits(self, newValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMaximumIntegerDigits(self, newValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMinimumFractionDigits(self, newValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMinimumIntegerDigits(self, newValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMultiplier(self, newValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def setNegativePrefix(self, newValue: str | java.lang.String, /) -> None: ...
    def setNegativeSuffix(self, newValue: str | java.lang.String, /) -> None: ...
    def setParseBigDecimal(self, newValue: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setParseIntegerOnly(self, value: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setPositivePrefix(self, newValue: str | java.lang.String, /) -> None: ...
    def setPositiveSuffix(self, newValue: str | java.lang.String, /) -> None: ...
    def setRoundingMode(self, roundingMode: java.math.RoundingMode, /) -> None: ...
    def toLocalizedPattern(self) -> str: ...
    def toPattern(self) -> str: ...

class DecimalFormatSymbols(java.io.Serializable, java.lang.Cloneable):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, locale: java.util.Locale, /) -> None: ...
    def clone(self) -> java.lang.Object: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def getAvailableLocales() -> java.chaquopy.JavaArray[java.util.Locale]: ...
    def getCurrency(self) -> java.util.Currency: ...
    def getCurrencySymbol(self) -> str: ...
    def getDecimalSeparator(self) -> str: ...
    def getDigit(self) -> str: ...
    def getExponentSeparator(self) -> str: ...
    def getGroupingSeparator(self) -> str: ...
    def getInfinity(self) -> str: ...
    @typing.overload
    @staticmethod
    def getInstance() -> DecimalFormatSymbols: ...
    @typing.overload
    @staticmethod
    def getInstance(locale: java.util.Locale, /) -> DecimalFormatSymbols: ...
    def getInternationalCurrencySymbol(self) -> str: ...
    def getMinusSign(self) -> str: ...
    def getMonetaryDecimalSeparator(self) -> str: ...
    def getMonetaryGroupingSeparator(self) -> str: ...
    def getNaN(self) -> str: ...
    def getPatternSeparator(self) -> str: ...
    def getPerMill(self) -> str: ...
    def getPercent(self) -> str: ...
    def getZeroDigit(self) -> str: ...
    def hashCode(self) -> int: ...
    def setCurrency(self, currency: java.util.Currency, /) -> None: ...
    def setCurrencySymbol(self, currency: str | java.lang.String, /) -> None: ...
    def setDecimalSeparator(self, decimalSeparator: str | java.jchar | java.lang.Character, /) -> None: ...
    def setDigit(self, digit: str | java.jchar | java.lang.Character, /) -> None: ...
    def setExponentSeparator(self, exp: str | java.lang.String, /) -> None: ...
    def setGroupingSeparator(self, groupingSeparator: str | java.jchar | java.lang.Character, /) -> None: ...
    def setInfinity(self, infinity: str | java.lang.String, /) -> None: ...
    def setInternationalCurrencySymbol(self, currencyCode: str | java.lang.String, /) -> None: ...
    def setMinusSign(self, minusSign: str | java.jchar | java.lang.Character, /) -> None: ...
    def setMonetaryDecimalSeparator(self, sep: str | java.jchar | java.lang.Character, /) -> None: ...
    def setMonetaryGroupingSeparator(self, monetaryGroupingSeparator: str | java.jchar | java.lang.Character, /) -> None: ...
    def setNaN(self, NaN: str | java.lang.String, /) -> None: ...
    def setPatternSeparator(self, patternSeparator: str | java.jchar | java.lang.Character, /) -> None: ...
    def setPerMill(self, perMill: str | java.jchar | java.lang.Character, /) -> None: ...
    def setPercent(self, percent: str | java.jchar | java.lang.Character, /) -> None: ...
    def setZeroDigit(self, zeroDigit: str | java.jchar | java.lang.Character, /) -> None: ...

class FieldPosition(java.lang.Object):
    @typing.overload
    def __init__(self, field: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, attribute: Format.Field, /) -> None: ...
    @typing.overload
    def __init__(self, attribute: Format.Field, fieldID: int | java.jint | java.lang.Integer, /) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getBeginIndex(self) -> int: ...
    def getEndIndex(self) -> int: ...
    def getField(self) -> int: ...
    def getFieldAttribute(self) -> Format.Field: ...
    def hashCode(self) -> int: ...
    def setBeginIndex(self, bi: int | java.jint | java.lang.Integer, /) -> None: ...
    def setEndIndex(self, ei: int | java.jint | java.lang.Integer, /) -> None: ...
    def toString(self) -> str: ...

class Format(java.io.Serializable, java.lang.Cloneable):
    def __init__(self) -> None: ...
    def clone(self) -> java.lang.Object: ...
    @typing.overload
    def format(self, obj: java.lang.Object | int | bool | float | str, /) -> str: ...
    @typing.overload
    def format(self, arg1: java.lang.Object | int | bool | float | str, arg2: java.lang.StringBuffer, arg3: FieldPosition, /) -> java.lang.StringBuffer: ...
    def formatToCharacterIterator(self, obj: java.lang.Object | int | bool | float | str, /) -> AttributedCharacterIterator: ...
    @typing.overload
    def parseObject(self, source: str | java.lang.String, /) -> java.lang.Object: ...
    @typing.overload
    def parseObject(self, arg1: str | java.lang.String, arg2: ParsePosition, /) -> java.lang.Object: ...

    class Field(AttributedCharacterIterator.Attribute):
        def __init__(self, name: str | java.lang.String, /) -> None: ...

class MessageFormat(Format):
    @typing.overload
    def __init__(self, pattern: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, pattern: str | java.lang.String, locale: java.util.Locale, /) -> None: ...
    def applyPattern(self, pattern: str | java.lang.String, /) -> None: ...
    def clone(self) -> java.lang.Object: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @typing.overload
    @staticmethod
    def format(pattern: str | java.lang.String, /, *arguments: java.lang.Object) -> str: ...
    @typing.overload
    def format(self, arguments: java.lang.Object | int | bool | float | str, result: java.lang.StringBuffer, pos: FieldPosition, /) -> java.lang.StringBuffer: ...
    @typing.overload
    def format(self, arguments: java.chaquopy.JavaArray[java.lang.Object], result: java.lang.StringBuffer, pos: FieldPosition, /) -> java.lang.StringBuffer: ...
    def formatToCharacterIterator(self, arguments: java.lang.Object | int | bool | float | str, /) -> AttributedCharacterIterator: ...
    def getFormats(self) -> java.chaquopy.JavaArray[Format]: ...
    def getFormatsByArgumentIndex(self) -> java.chaquopy.JavaArray[Format]: ...
    def getLocale(self) -> java.util.Locale: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def parse(self, source: str | java.lang.String, /) -> java.chaquopy.JavaArray[java.lang.Object]: ...
    @typing.overload
    def parse(self, source: str | java.lang.String, pos: ParsePosition, /) -> java.chaquopy.JavaArray[java.lang.Object]: ...
    def parseObject(self, source: str | java.lang.String, pos: ParsePosition, /) -> java.lang.Object: ...
    def setFormat(self, formatElementIndex: int | java.jint | java.lang.Integer, newFormat: Format, /) -> None: ...
    def setFormatByArgumentIndex(self, argumentIndex: int | java.jint | java.lang.Integer, newFormat: Format, /) -> None: ...
    def setFormats(self, newFormats: java.chaquopy.JavaArray[Format], /) -> None: ...
    def setFormatsByArgumentIndex(self, newFormats: java.chaquopy.JavaArray[Format], /) -> None: ...
    def setLocale(self, locale: java.util.Locale, /) -> None: ...
    def toPattern(self) -> str: ...

    class Field(Format.Field):
        ARGUMENT: typing.ClassVar[MessageFormat.Field] = ...
        def __init__(self, name: str | java.lang.String, /) -> None: ...
        def readResolve(self) -> java.lang.Object: ...

class Normalizer(java.lang.Object):
    @staticmethod
    def isNormalized(src: java.lang.CharSequence, form: Normalizer.Form, /) -> bool: ...
    @staticmethod
    def normalize(src: java.lang.CharSequence, form: Normalizer.Form, /) -> str: ...

    class Form(java.lang.Enum[Normalizer.Form]):
        NFC: typing.ClassVar[Normalizer.Form] = ...
        NFD: typing.ClassVar[Normalizer.Form] = ...
        NFKC: typing.ClassVar[Normalizer.Form] = ...
        NFKD: typing.ClassVar[Normalizer.Form] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> Normalizer.Form: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[Normalizer.Form]: ...

class NumberFormat(Format):
    FRACTION_FIELD: typing.ClassVar[int] = ...
    INTEGER_FIELD: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def clone(self) -> java.lang.Object: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @typing.overload
    def format(self, number: float | java.jdouble | java.lang.Double, /) -> str: ...
    @typing.overload
    def format(self, number: int | java.jlong | java.lang.Long, /) -> str: ...
    @typing.overload
    def format(self, arg1: float | java.jdouble | java.lang.Double, arg2: java.lang.StringBuffer, arg3: FieldPosition, /) -> java.lang.StringBuffer: ...
    @typing.overload
    def format(self, arg1: int | java.jlong | java.lang.Long, arg2: java.lang.StringBuffer, arg3: FieldPosition, /) -> java.lang.StringBuffer: ...
    @typing.overload
    def format(self, number: java.lang.Object | int | bool | float | str, toAppendTo: java.lang.StringBuffer, pos: FieldPosition, /) -> java.lang.StringBuffer: ...
    @staticmethod
    def getAvailableLocales() -> java.chaquopy.JavaArray[java.util.Locale]: ...
    def getCurrency(self) -> java.util.Currency: ...
    @typing.overload
    @staticmethod
    def getCurrencyInstance() -> NumberFormat: ...
    @typing.overload
    @staticmethod
    def getCurrencyInstance(inLocale: java.util.Locale, /) -> NumberFormat: ...
    @typing.overload
    @staticmethod
    def getInstance() -> NumberFormat: ...
    @typing.overload
    @staticmethod
    def getInstance(inLocale: java.util.Locale, /) -> NumberFormat: ...
    @typing.overload
    @staticmethod
    def getIntegerInstance() -> NumberFormat: ...
    @typing.overload
    @staticmethod
    def getIntegerInstance(inLocale: java.util.Locale, /) -> NumberFormat: ...
    def getMaximumFractionDigits(self) -> int: ...
    def getMaximumIntegerDigits(self) -> int: ...
    def getMinimumFractionDigits(self) -> int: ...
    def getMinimumIntegerDigits(self) -> int: ...
    @typing.overload
    @staticmethod
    def getNumberInstance() -> NumberFormat: ...
    @typing.overload
    @staticmethod
    def getNumberInstance(inLocale: java.util.Locale, /) -> NumberFormat: ...
    @typing.overload
    @staticmethod
    def getPercentInstance() -> NumberFormat: ...
    @typing.overload
    @staticmethod
    def getPercentInstance(inLocale: java.util.Locale, /) -> NumberFormat: ...
    def getRoundingMode(self) -> java.math.RoundingMode: ...
    def hashCode(self) -> int: ...
    def isGroupingUsed(self) -> bool: ...
    def isParseIntegerOnly(self) -> bool: ...
    @typing.overload
    def parse(self, source: str | java.lang.String, /) -> java.lang.Number: ...
    @typing.overload
    def parse(self, arg1: str | java.lang.String, arg2: ParsePosition, /) -> java.lang.Number: ...
    def parseObject(self, source: str | java.lang.String, pos: ParsePosition, /) -> java.lang.Object: ...
    def setCurrency(self, currency: java.util.Currency, /) -> None: ...
    def setGroupingUsed(self, newValue: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setMaximumFractionDigits(self, newValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMaximumIntegerDigits(self, newValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMinimumFractionDigits(self, newValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMinimumIntegerDigits(self, newValue: int | java.jint | java.lang.Integer, /) -> None: ...
    def setParseIntegerOnly(self, value: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setRoundingMode(self, roundingMode: java.math.RoundingMode, /) -> None: ...

    class Field(Format.Field):
        CURRENCY: typing.ClassVar[NumberFormat.Field] = ...
        DECIMAL_SEPARATOR: typing.ClassVar[NumberFormat.Field] = ...
        EXPONENT: typing.ClassVar[NumberFormat.Field] = ...
        EXPONENT_SIGN: typing.ClassVar[NumberFormat.Field] = ...
        EXPONENT_SYMBOL: typing.ClassVar[NumberFormat.Field] = ...
        FRACTION: typing.ClassVar[NumberFormat.Field] = ...
        GROUPING_SEPARATOR: typing.ClassVar[NumberFormat.Field] = ...
        INTEGER: typing.ClassVar[NumberFormat.Field] = ...
        PERCENT: typing.ClassVar[NumberFormat.Field] = ...
        PERMILLE: typing.ClassVar[NumberFormat.Field] = ...
        SIGN: typing.ClassVar[NumberFormat.Field] = ...
        def __init__(self, name: str | java.lang.String, /) -> None: ...
        def readResolve(self) -> java.lang.Object: ...

class ParseException(java.lang.Exception):
    def __init__(self, s: str | java.lang.String, errorOffset: int | java.jint | java.lang.Integer, /) -> None: ...
    def getErrorOffset(self) -> int: ...

class ParsePosition(java.lang.Object):
    def __init__(self, index: int | java.jint | java.lang.Integer, /) -> None: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getErrorIndex(self) -> int: ...
    def getIndex(self) -> int: ...
    def hashCode(self) -> int: ...
    def setErrorIndex(self, ei: int | java.jint | java.lang.Integer, /) -> None: ...
    def setIndex(self, index: int | java.jint | java.lang.Integer, /) -> None: ...
    def toString(self) -> str: ...

class RuleBasedCollator(Collator):
    def __init__(self, rules: str | java.lang.String, /) -> None: ...
    def clone(self) -> java.lang.Object: ...
    def compare(self, source: str | java.lang.String, target: str | java.lang.String, /) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @typing.overload
    def getCollationElementIterator(self, source: str | java.lang.String, /) -> CollationElementIterator: ...
    @typing.overload
    def getCollationElementIterator(self, source: CharacterIterator, /) -> CollationElementIterator: ...
    def getCollationKey(self, source: str | java.lang.String, /) -> CollationKey: ...
    def getRules(self) -> str: ...
    def hashCode(self) -> int: ...

class SimpleDateFormat(DateFormat):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, pattern: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, pattern: str | java.lang.String, formatSymbols: DateFormatSymbols, /) -> None: ...
    @typing.overload
    def __init__(self, pattern: str | java.lang.String, locale: java.util.Locale, /) -> None: ...
    def applyLocalizedPattern(self, pattern: str | java.lang.String, /) -> None: ...
    def applyPattern(self, pattern: str | java.lang.String, /) -> None: ...
    def clone(self) -> java.lang.Object: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def format(self, date: java.util.Date, toAppendTo: java.lang.StringBuffer, pos: FieldPosition, /) -> java.lang.StringBuffer: ...
    def formatToCharacterIterator(self, obj: java.lang.Object | int | bool | float | str, /) -> AttributedCharacterIterator: ...
    def get2DigitYearStart(self) -> java.util.Date: ...
    def getDateFormatSymbols(self) -> DateFormatSymbols: ...
    def hashCode(self) -> int: ...
    def parse(self, text: str | java.lang.String, pos: ParsePosition, /) -> java.util.Date: ...
    def set2DigitYearStart(self, startDate: java.util.Date, /) -> None: ...
    def setDateFormatSymbols(self, newFormatSymbols: DateFormatSymbols, /) -> None: ...
    def toLocalizedPattern(self) -> str: ...
    def toPattern(self) -> str: ...

class StringCharacterIterator(CharacterIterator):
    @typing.overload
    def __init__(self, text: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, text: str | java.lang.String, pos: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, text: str | java.lang.String, begin: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, pos: int | java.jint | java.lang.Integer, /) -> None: ...
    def clone(self) -> java.lang.Object: ...
    def current(self) -> str: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def first(self) -> str: ...
    def getBeginIndex(self) -> int: ...
    def getEndIndex(self) -> int: ...
    def getIndex(self) -> int: ...
    def hashCode(self) -> int: ...
    def last(self) -> str: ...
    def next(self) -> str: ...
    def previous(self) -> str: ...
    def setIndex(self, p: int | java.jint | java.lang.Integer, /) -> str: ...
    def setText(self, text: str | java.lang.String, /) -> None: ...



import typing

import java
import java.lang
import org.xml.sax
import org.xmlpull.v1

class Driver(org.xml.sax.Attributes, org.xml.sax.Locator, org.xml.sax.XMLReader):
    APACHE_DYNAMIC_VALIDATION_FEATURE: typing.ClassVar[str] = ...
    APACHE_SCHEMA_VALIDATION_FEATURE: typing.ClassVar[str] = ...
    DECLARATION_HANDLER_PROPERTY: typing.ClassVar[str] = ...
    LEXICAL_HANDLER_PROPERTY: typing.ClassVar[str] = ...
    NAMESPACES_FEATURE: typing.ClassVar[str] = ...
    NAMESPACE_PREFIXES_FEATURE: typing.ClassVar[str] = ...
    VALIDATION_FEATURE: typing.ClassVar[str] = ...
    contentHandler: org.xml.sax.ContentHandler = ...
    errorHandler: org.xml.sax.ErrorHandler = ...
    pp: org.xmlpull.v1.XmlPullParser = ...
    systemId: str = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, pp: org.xmlpull.v1.XmlPullParser, /) -> None: ...
    def getColumnNumber(self) -> int: ...
    def getContentHandler(self) -> org.xml.sax.ContentHandler: ...
    def getDTDHandler(self) -> org.xml.sax.DTDHandler: ...
    def getEntityResolver(self) -> org.xml.sax.EntityResolver: ...
    def getErrorHandler(self) -> org.xml.sax.ErrorHandler: ...
    def getFeature(self, name: str | java.lang.String, /) -> bool: ...
    @typing.overload
    def getIndex(self, qName: str | java.lang.String, /) -> int: ...
    @typing.overload
    def getIndex(self, uri: str | java.lang.String, localName: str | java.lang.String, /) -> int: ...
    def getLength(self) -> int: ...
    def getLineNumber(self) -> int: ...
    def getLocalName(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    def getProperty(self, name: str | java.lang.String, /) -> java.lang.Object: ...
    def getPublicId(self) -> str: ...
    def getQName(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    def getSystemId(self) -> str: ...
    @typing.overload
    def getType(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def getType(self, qName: str | java.lang.String, /) -> str: ...
    @typing.overload
    def getType(self, uri: str | java.lang.String, localName: str | java.lang.String, /) -> str: ...
    def getURI(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def getValue(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def getValue(self, qName: str | java.lang.String, /) -> str: ...
    @typing.overload
    def getValue(self, uri: str | java.lang.String, localName: str | java.lang.String, /) -> str: ...
    @typing.overload
    def parse(self, systemId: str | java.lang.String, /) -> None: ...
    @typing.overload
    def parse(self, source: org.xml.sax.InputSource, /) -> None: ...
    def parseSubTree(self, pp: org.xmlpull.v1.XmlPullParser, /) -> None: ...
    def setContentHandler(self, handler: org.xml.sax.ContentHandler, /) -> None: ...
    def setDTDHandler(self, handler: org.xml.sax.DTDHandler, /) -> None: ...
    def setEntityResolver(self, resolver: org.xml.sax.EntityResolver, /) -> None: ...
    def setErrorHandler(self, handler: org.xml.sax.ErrorHandler, /) -> None: ...
    def setFeature(self, name: str | java.lang.String, value: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setProperty(self, name: str | java.lang.String, value: java.lang.Object | int | bool | float | str, /) -> None: ...
    def startElement(self, namespace: str | java.lang.String, localName: str | java.lang.String, qName: str | java.lang.String, /) -> None: ...
